==> manaplus_1.6.5.7.orig.tar.xz: manaplus-1.6.5.7/src/net/tmwa/mercenaryhandler.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2011-2016  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef NET_TMWA_MERCENARYHANDLER_H
#define NET_TMWA_MERCENARYHANDLER_H

#ifdef EATHENA_SUPPORT

#include "net/mercenaryhandler.h"

namespace TmwAthena
{

class MercenaryHandler final : public Net::MercenaryHandler
{
    public:
        MercenaryHandler();

        A_DELETE_COPY(MercenaryHandler)

        void fire() const override final A_CONST;

        void moveToMaster() const override final A_CONST;

        void move(const int x, const int y) const override final A_CONST;

        void attack(const BeingId targetId,
                    const Keep keep) const override final A_CONST;

        void talk(const std::string &restrict text) const override final
                  A_CONST;

        void emote(const uint8_t emoteId) const override final A_CONST;

        void setDirection(const unsigned char type) const override final
                          A_CONST;
};

}  // namespace TmwAthena

#endif  // EATHENA_SUPPORT
#endif  // NET_TMWA_MERCENARYHANDLER_H

==> manaplus_1.8.2.17.orig.tar.xz: manaplus-1.8.2.17/src/net/tmwa/mercenaryhandler.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2011-2018  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef NET_TMWA_MERCENARYHANDLER_H
#define NET_TMWA_MERCENARYHANDLER_H

#include "net/mercenaryhandler.h"

namespace TmwAthena
{

class MercenaryHandler final : public Net::MercenaryHandler
{
    public:
        MercenaryHandler();

        A_DELETE_COPY(MercenaryHandler)

        ~MercenaryHandler() override final;

        void fire() const override final;

        void moveToMaster() const override final;

        void move(const int x, const int y) const override final;

        void attack(const BeingId targetId,
                    const Keep keep) const override final;

        void talk(const std::string &restrict text) const override final;

        void emote(const uint8_t emoteId) const override final;

        void setDirection(const unsigned char type) const override final;
};

}  // namespace TmwAthena

#endif  // NET_TMWA_MERCENARYHANDLER_H
